summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--docs/design/part-element-sink.txt4
-rw-r--r--docs/design/part-events.txt2
-rw-r--r--libs/gst/base/gstbaseparse.c8
-rw-r--r--libs/gst/base/gstbasesink.c2
-rw-r--r--libs/gst/base/gstbasesrc.c4
-rw-r--r--plugins/elements/gstidentity.c2
-rw-r--r--plugins/elements/gstoutputselector.c2
7 files changed, 12 insertions, 12 deletions
diff --git a/docs/design/part-element-sink.txt b/docs/design/part-element-sink.txt
index 6cda060d6c..b0561cdfc8 100644
--- a/docs/design/part-element-sink.txt
+++ b/docs/design/part-element-sink.txt
@@ -178,8 +178,8 @@ sink overview
PREROLL_UNLOCK
STREAM_UNLOCK
break
- NEWSEGMENT:
- # the newsegment must be used to clip incoming
+ SEGMENT:
+ # the segment must be used to clip incoming
# buffers. Then then go into the queue as non-prerollable
# items used for syncing the buffers
STREAM_LOCK
diff --git a/docs/design/part-events.txt b/docs/design/part-events.txt
index 001e8b7ef4..6e81b5a6a1 100644
--- a/docs/design/part-events.txt
+++ b/docs/design/part-events.txt
@@ -248,7 +248,7 @@ The general flow of executing the seek with FLUSH is as follows:
4) send a FLUSH_STOP event to all peer elements to allow streaming again.
- 5) create a NEWSEGMENT event to signal the new buffer timestamp base time.
+ 5) create a SEGMENT event to signal the new buffer timestamp base time.
This event must be queued to be sent by the streaming thread.
6) start stopped tasks and unlock the STREAM_LOCK, dataflow will continue
diff --git a/libs/gst/base/gstbasesink.c b/libs/gst/base/gstbasesink.c
index 0d248f6f49..31679db465 100644
--- a/libs/gst/base/gstbasesink.c
+++ b/libs/gst/base/gstbasesink.c
@@ -84,7 +84,7 @@
* element receives EOS in PAUSED, preroll completes, the event is queued and an
* EOS message is posted when going to PLAYING.
*
- * #GstBaseSink will internally use the #GST_EVENT_NEWSEGMENT events to schedule
+ * #GstBaseSink will internally use the #GST_EVENT_SEGMENT events to schedule
* synchronisation and clipping of buffers. Buffers that fall completely outside
* of the current segment are dropped. Buffers that fall partially in the
* segment are rendered (and prerolled). Subclasses should do any subbuffer
diff --git a/libs/gst/base/gstbasesrc.c b/libs/gst/base/gstbasesrc.c
index d845517e84..70578b4b67 100644
--- a/libs/gst/base/gstbasesrc.c
+++ b/libs/gst/base/gstbasesrc.c
@@ -35,7 +35,7 @@
*
* The source can be configured to operate in any #GstFormat with the
* gst_base_src_set_format() method. The currently set format determines
- * the format of the internal #GstSegment and any #GST_EVENT_NEWSEGMENT
+ * the format of the internal #GstSegment and any #GST_EVENT_SEGMENT
* events. The default format for #GstBaseSrc is #GST_FORMAT_BYTES.
*
* #GstBaseSrc always supports push mode scheduling. If the following
@@ -577,7 +577,7 @@ gst_base_src_is_live (GstBaseSrc * src)
* @format: the format to use
*
* Sets the default format of the source. This will be the format used
- * for sending NEW_SEGMENT events and for performing seeks.
+ * for sending SEGMENT events and for performing seeks.
*
* If a format of GST_FORMAT_BYTES is set, the element will be able to
* operate in pull mode if the #GstBaseSrcClass.is_seekable() returns TRUE.
diff --git a/plugins/elements/gstidentity.c b/plugins/elements/gstidentity.c
index b09907a594..c33d263d3a 100644
--- a/plugins/elements/gstidentity.c
+++ b/plugins/elements/gstidentity.c
@@ -327,7 +327,7 @@ gst_identity_sink_event (GstBaseTransform * trans, GstEvent * event)
}
}
- /* Reset previous timestamp, duration and offsets on NEWSEGMENT
+ /* Reset previous timestamp, duration and offsets on SEGMENT
* to prevent false warnings when checking for perfect streams */
if (GST_EVENT_TYPE (event) == GST_EVENT_SEGMENT) {
identity->prev_timestamp = identity->prev_duration = GST_CLOCK_TIME_NONE;
diff --git a/plugins/elements/gstoutputselector.c b/plugins/elements/gstoutputselector.c
index b9476afb5a..99dc05114d 100644
--- a/plugins/elements/gstoutputselector.c
+++ b/plugins/elements/gstoutputselector.c
@@ -454,7 +454,7 @@ gst_output_selector_chain (GstPad * pad, GstObject * parent, GstBuffer * buf)
osel->latest_buffer = gst_buffer_ref (buf);
}
- /* Keep track of last stop and use it in NEWSEGMENT start after
+ /* Keep track of last stop and use it in SEGMENT start after
switching to a new src pad */
position = GST_BUFFER_TIMESTAMP (buf);
if (GST_CLOCK_TIME_IS_VALID (position)) {
diff --git a/libs/gst/base/gstbaseparse.c b/libs/gst/base/gstbaseparse.c
index f75b148746..2d52cf7192 100644
--- a/libs/gst/base/gstbaseparse.c
+++ b/libs/gst/base/gstbaseparse.c
@@ -35,7 +35,7 @@
* <listitem><para>handles state changes</para></listitem>
* <listitem><para>can operate in pull mode or push mode</para></listitem>
* <listitem><para>handles seeking in both modes</para></listitem>
- * <listitem><para>handles events (NEWSEGMENT/EOS/FLUSH)</para></listitem>
+ * <listitem><para>handles events (SEGMENT/EOS/FLUSH)</para></listitem>
* <listitem><para>
* handles queries (POSITION/DURATION/SEEKING/FORMAT/CONVERT)
* </para></listitem>
@@ -2036,7 +2036,7 @@ gst_base_parse_push_frame (GstBaseParse * parse, GstBaseParseFrame * frame)
gst_base_parse_check_media (parse);
}
/* Push pending events, including NEWSEGMENT events */
if (G_UNLIKELY (parse->priv->pending_events)) {
GList *r = g_list_reverse (parse->priv->pending_events);
GList *l;
@@ -2070,7 +2070,7 @@ gst_base_parse_push_frame (GstBaseParse * parse, GstBaseParseFrame * frame)
GST_DEBUG_OBJECT (parse,
"Gap of %" G_GINT64_FORMAT " ns detected in stream " "(%"
GST_TIME_FORMAT " -> %" GST_TIME_FORMAT "). "
- "Sending updated NEWSEGMENT events", diff,
+ "Sending updated SEGMENT events", diff,
GST_TIME_ARGS (parse->segment.position),
GST_TIME_ARGS (last_start));
@@ -3041,7 +3041,7 @@ pause:
push_eos = TRUE;
}
if (push_eos) {
/* Push pending events, including NEWSEGMENT events */
if (G_UNLIKELY (parse->priv->pending_events)) {
GList *r = g_list_reverse (parse->priv->pending_events);
GList *l;
@@ -2036,7 +2036,7 @@ gst_base_parse_push_frame (GstBaseParse * parse, GstBaseParseFrame * frame)
gst_base_parse_check_media (parse);
}
- /* Push pending events, including NEWSEGMENT events */
+ /* Push pending events, including SEGMENT events */
if (G_UNLIKELY (parse->priv->pending_events)) {
GList *r = g_list_reverse (parse->priv->pending_events);
@@ -3041,7 +3041,7 @@ pause:
}
if (push_eos) {
- /* Push pending events, including NEWSEGMENT events */
+ /* Push pending events, including SEGMENT events */
if (G_UNLIKELY (parse->priv->pending_events)) {
GList *r = g_list_reverse (parse->priv->pending_events);